# Generated by Django 4.2.23 on 2025-09-11 23:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0002_delete_pypi'),
    ]

    operations = [
        migrations.CreateModel(
            name='ASNDetail',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('project', models.CharField(default='bomiot', max_length=255, verbose_name='Project Name')),
                ('is_delete', models.BooleanField(default=False, verbose_name='Delete Label')),
                ('created_time', models.DateTimeField(auto_now_add=True, verbose_name='Created Time')),
                ('updated_time', models.DateTimeField(auto_now=True, null=True, verbose_name='Updated Time')),
                ('data', models.JSONField()),
            ],
            options={
                'verbose_name': 'bomiot ASN Detail',
                'verbose_name_plural': 'bomiot ASN Detail',
                'db_table': 'bomiot_asn_detail',
                'ordering': ['-id'],
            },
        ),
        migrations.CreateModel(
            name='DNDetail',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('project', models.CharField(default='bomiot', max_length=255, verbose_name='Project Name')),
                ('is_delete', models.BooleanField(default=False, verbose_name='Delete Label')),
                ('created_time', models.DateTimeField(auto_now_add=True, verbose_name='Created Time')),
                ('updated_time', models.DateTimeField(auto_now=True, null=True, verbose_name='Updated Time')),
                ('data', models.JSONField()),
            ],
            options={
                'verbose_name': 'bomiot DN Detail',
                'verbose_name_plural': 'bomiot DN Detail',
                'db_table': 'bomiot_dn_detail',
                'ordering': ['-id'],
            },
        ),
        migrations.CreateModel(
            name='StockBin',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('project', models.CharField(default='bomiot', max_length=255, verbose_name='Project Name')),
                ('is_delete', models.BooleanField(default=False, verbose_name='Delete Label')),
                ('created_time', models.DateTimeField(auto_now_add=True, verbose_name='Created Time')),
                ('updated_time', models.DateTimeField(auto_now=True, null=True, verbose_name='Updated Time')),
                ('data', models.JSONField()),
            ],
            options={
                'verbose_name': 'bomiot Stock Bin',
                'verbose_name_plural': 'bomiot Stock Bin',
                'db_table': 'bomiot_stock_bin',
                'ordering': ['-id'],
            },
        ),
        migrations.DeleteModel(
            name='API',
        ),
        migrations.AddField(
            model_name='asn',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='bar',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='bin',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='capital',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='customer',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='dn',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='driver',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='example',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='fee',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='goods',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='purchase',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='stock',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='supplier',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
        migrations.AddField(
            model_name='team',
            name='project',
            field=models.CharField(default='bomiot', max_length=255, verbose_name='Project Name'),
        ),
    ]
