import{Q as s}from"./QPage-ltF7SocP.js";import{u as n}from"./use-meta-CzUauSHJ.js";import{u as m,_ as c}from"./MDParser-F33_EmLG.js";import{r as e,o as i,j as p,ad as u,a5 as d,a9 as f,a8 as l}from"./index-C_Y_PPsx.js";import"./rightDrawer-D525rTZu.js";import"./axios-CfM96r7k.js";import"./_commonjsHelpers-Cpj98o6Y.js";import"./use-quasar-3xwWZP-X.js";import"./language-B_adsXDX.js";import"./vue-i18n.runtime-BehzTcvC.js";const P={__name:"PoetryReader",setup(_){const t=e(""),o=e(""),a=e(""),r=m();return n(()=>({title:t.value,meta:{description:{name:"description",content:o.value},keywords:{name:"keywords",content:a.value}}})),i(()=>{r.docNameChange("poetry")}),p(()=>{}),(k,x)=>(d(),u(s,{class:"flex flex-top"},{default:f(()=>[l(c)]),_:1}))}};export{P as default};
